Lua_LuckyTurntableStageRewardPanel = class("Lua_LuckyTurntableStageRewardPanel", Lua_DisplayObject)
function Lua_LuckyTurntableStageRewardPanel:ctor(p)
	self:superCall("ctor", p, "LuckyTurntableStageRewardPanel_skin");
end

function Lua_LuckyTurntableStageRewardPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.rectW = 576;
	self.rectH = 88;
	self.subRectW = self.rectW;
	self.subRectH = 88;
	self.subMinPos = -(self.subRectW - self.rectW) / 2;
	self.subMaxPox = -self.subMinPos;
	self.spaceW = 112;
	self.stageArr = Array();

	self.scrollContainer = UICreate.createScrollContainer(self.content, 0, 0, self.rectW, self.rectH);
	self.scrollContainer.horizontal = true;
	self.scrollContainer.vertical = false;
	self.scrollContainer.movementTypeValue = 1;
	self.scrollContainer.elasticity = 0.3;
	self.scrollContainer.inertia = true;
	self.scrollContainer.siblingIndex = 0;
	self.scrollContainer:setScrollAnchor(0.5, 0.5, 0.5, 0.5);
	self.scrollContainer:setScrollPivot(4);
	self.scrollContainer:addRectMask2D();
	self.scrollContainer:addMousDownFuntion(self, self.onMouseDownFun);
	self.scrollContainer:addMouseUpFuntion(self, self.onMouseUpFun);
	self.scrollContainer:setLocation(50, 0, 0);

	self.sub = self.scrollContainer.scrollContent;
	self.timesBar = UICreate.createProgressBar(self.sub, "turntable_atlas", "ui_xyzp_toggle_004_b",
		"turntable_atlas", "ui_xyzp_toggle_004_f", -self.rectW / 2, 0, self.rectW, 10);
	self.timesBar.pivot = Lua_WindowUtil.getPivot(3);

	self:addLuaEvent("UPDATE_LUCKY_TURNTABLE_CUMULATEDRAWINFO", self, self.updateCumulateDrawInfo);
end

function Lua_LuckyTurntableStageRewardPanel:setSelectTypeInfo(selectType)
	Lua_ProxyManager.getProxy("Lua_LuckyTurntableProxy"):sCumulateDrawInfo(selectType);
end

function Lua_LuckyTurntableStageRewardPanel:updateCumulateDrawInfo(msg)
	local rewardList = msg.accept_reward_state;
	table.sort(rewardList, function(a, b) return a.key < b.key end);
	local dataLen = #rewardList;
	local vo = DataCenter.luckyTurntableData:getTheStageRewardVo(rewardList[dataLen].key);
	local barWidth = dataLen * self.spaceW;
	self.subRectW = barWidth + 38; -- 38 item的宽
	local halfSubRectW = self.subRectW / 2;
	if self.turnTableType ~= msg.turntable_type or self.round ~= vo.round then
		self.subMinPos = -(self.subRectW - self.rectW) / 2;
		self.subMaxPox = -self.subMinPos;
		self.scrollContainer.horizontal = dataLen > 5;
		self.scrollContainer:setScrollSize(self.subRectW, self.subRectH);
		self.scrollContainer:setScrollPosition(self.subMaxPox, 0, 0);

		self.timesBar:SetDimensions(barWidth, 10);
		self.timesBar:setLocation(-halfSubRectW, 8, 0);
	end
	self.turnTableType = msg.turntable_type;
	self.round = vo.round;

	local times = msg.draw_time;
	self.timesTxt.text = times;

	local maxValue = vo.times;
	local value = 0;
	local index = 1;
	if times >= maxValue then
		value = maxValue;
	else
		for i = 1, dataLen do
			vo = DataCenter.luckyTurntableData:getTheStageRewardVo(rewardList[i].key);
			if vo.times >= times then
				index = i;
				break;
			end
		end

		local num;
		local stepSpace = maxValue / dataLen;
		vo = DataCenter.luckyTurntableData:getTheStageRewardVo(rewardList[index].key);
		value = value + stepSpace * (index - 1);
		if index <= 1 then
			num = stepSpace / vo.times;
			value = value + times * num;
		else
			local preVo = DataCenter.luckyTurntableData:getTheStageRewardVo(rewardList[index - 1].key);
			num = stepSpace / (vo.times - preVo.times);
			value = value + (times - preVo.times) * num;
		end
	end
	self.timesBar:setMaxValue(maxValue);
	self.timesBar:setValue(value);
	
	local hasLen = self.stageArr:getSize();
	local maxLen = dataLen > hasLen and dataLen or hasLen;
	local item;
	local index = 1;
	for i = 1, maxLen do
		item = self.stageArr[i];
		if i > dataLen then
			if item ~= nil then
				item:setEnable(false);
			end
		else
			vo = DataCenter.luckyTurntableData:getTheStageRewardVo(rewardList[i].key);
			if vo.receiveStage == 2 then index = i end
			if item == nil then
				item = Lua_LuckyTurntableStageRewardItem.new(self.sub);
				item.contentName = "Lua_LuckyTurntableStageRewardItem_" .. i;
				self.stageArr:add(item);
			end
			item:setEnable(true);
			item:setLocation(i / dataLen * barWidth - halfSubRectW, 2, 0);
			item:setData(vo);
		end
	end
	self:moveToIndex(dataLen > 5 and index or 5);
end

function Lua_LuckyTurntableStageRewardPanel:moveToIndex(idx)
	local targetPos = self.subMaxPox;
	for i = 1, idx - 1 do
		targetPos = targetPos - self.spaceW;
	end

	if targetPos > self.subMaxPox then
		targetPos = self.subMaxPox;
	elseif targetPos < self.subMinPos then
		targetPos = self.subMinPos;
	end
	self.scrollContainer:setScrollPosition(targetPos, 0, 0);
end

function Lua_LuckyTurntableStageRewardPanel:onMouseDownFun()
	self.startMouseX = CommonUtil.mousePositionX;
	self.startMouseY = CommonUtil.mousePositionY;
	self.startClickTime = getTime();
end

function Lua_LuckyTurntableStageRewardPanel:onMouseUpFun()
	local dx = CommonUtil.mousePositionX - self.startMouseX;
	local dy = CommonUtil.mousePositionY - self.startMouseY;
	if getTime() - self.startClickTime <= 0.3 and Mathf.Abs(dx) + Mathf.Abs(dy) < 4 then
		self:checkPressItem();
	end
end

function Lua_LuckyTurntableStageRewardPanel:checkPressItem()
	local winPos = LuaUtil.getTouchPosInverseObj(self.sub);
	for i = 1, self.stageArr:getSize() do
		if self.stageArr[i].isActive and self.stageArr[i]:checkInBound(winPos.x, winPos.y) then
			self.stageArr[i]:onPressClick();
			break;
		end
	end
end

function Lua_LuckyTurntableStageRewardPanel:dispose()
	if self.scrollContainer ~= nil then
		self.scrollContainer:dispose();
		self.scrollContainer = nil;
	end
	if self.timesBar ~= nil then
		self.timesBar:dispose();
		self.timesBar = nil;
	end
	if self.stageArr ~= nil then
		self.stageArr:dispose();
		self.stageArr:clear();
		self.stageArr = nil;
	end
	self.sub = nil;
	self:superCall("dispose");
end










Lua_LuckyTurntableStageRewardItem = class("Lua_LuckyTurntableStageRewardItem", Lua_DisplayObject);
function Lua_LuckyTurntableStageRewardItem:ctor(p)
	self:superCall("ctor", p, "LuckyTurntableStageRewardItem_skin");
end

function Lua_LuckyTurntableStageRewardItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_LuckyTurntableStageRewardItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end
	
	local spriteName = data.receiveStage == 1 and "ui_xyzp_widget_011" or "ui_xyzp_widget_010";
	self.itemBg:setAltas("turntable_atlas", spriteName);
	self.itemIcon:setAltas(data.timesRewardVo.atlas, data.timesRewardVo.sprite);

	self.timesTxt.text = data.times;
	self.numTxt.text = data.timesRewardVo.count;

	self.drawIcon_1:setEnable(data.receiveStage == 2);
	self.drawIcon_2:setEnable(data.receiveStage == 2);
	self:showRedDot(data.receiveStage == 1);
end

function Lua_LuckyTurntableStageRewardItem:checkInBound(posX, posY)
	local minX = self.centerPosX - self.itemIcon.width / 2 * self.itemIcon.scaleX;
	local maxX = self.centerPosX + self.itemIcon.width / 2 * self.itemIcon.scaleX;
	local minY = self.centerPosY + 7 - self.itemIcon.height / 2 * self.itemIcon.scaleY;
	local maxY = self.centerPosY + 7 + self.itemIcon.height / 2 * self.itemIcon.scaleY;
	return posX >= minX and posX <= maxX and posY >= minY and posY <= maxY;
end

function Lua_LuckyTurntableStageRewardItem:onPressClick(go)
	if self._data.receiveStage == 1 then
		Lua_ProxyManager.getProxy("Lua_LuckyTurntableProxy"):sDrawCumulateTimesReward(self._data.turntable_type, self._data.id);
	else
		DataCenter.packUtil:showItemInfo(self._data.timesRewardVo);
	end
end

function Lua_LuckyTurntableStageRewardItem:showRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:createRedPointEff();
			self.redPoint:setScale(0.7, 0.7);
			self.redPoint:setLocation(17, 24, 0);
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_LuckyTurntableStageRewardItem:dispose()
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self._data = nil;
	self:superCall("dispose");
end